@@ -1,6 +1,7 @@
 import logging
 import signal
 import sys
+import threading
 import traceback
 import os.path
 from datetime import datetime, timedelta
@@ -12,6 +13,7 @@ from setproctitle import setproctitle
 from limpyd import __version__ as limpyd_version
 from limpyd.exceptions import DoesNotExist
 
+from limpyd_jobs.version import __version__ as limpyd_jobs_version
 from limpyd_jobs import STATUSES, LimpydJobsException, ConfigurationException
 from limpyd_jobs.models import Queue, Job, Error
 from limpyd_jobs.utils import import_class, total_seconds
@@ -30,7 +32,7 @@ class Worker(object):
 
     # logging information
     logger_name = LOGGER_NAME
-    logger_level = logging.ERROR
+    logger_level = logging.INFO
     save_errors = True
     save_tracebacks = True
 
@@ -176,7 +178,7 @@ class Worker(object):
         Return an identifier for the worker to use in logging
         """
         if not hasattr(self, '_id'):
-            self._id = '%x' % id(self)
+            self._id = str(threading.current_thread().ident + id(self))[-6:]
         return self._id
 
     def log(self, message, level='info'):
@@ -638,13 +640,6 @@ class WorkerConfig(object):
             help="Do not update the title of the worker's process, e.g. --no-title"),
     )
 
-    default_classes = {
-        'queue_model': Queue,
-        'error_model': Error,
-        'worker_class': Worker,
-        'callback': None,
-    }
-
     def __init__(self, argv=None):
         """
         Save arguments and program name
@@ -659,7 +654,8 @@ class WorkerConfig(object):
         Return the limpyd_jobs version. May be overriden for subclasses
 
         """
-        return '(redis-limpyd-jobs %s)' % limpyd_version
+        return '(redis-limpyd-jobs %s, redis-limpyd %s)' % (
+                                            limpyd_jobs_version, limpyd_version)
 
     def usage(self):
         """
@@ -731,26 +727,28 @@ class WorkerConfig(object):
 
         self.update_title = self.options.update_title
 
-    def do_import(self, name):
+    def do_import(self, name, default):
         """
         Import the given option (use default values if not defined on command line)
         """
-        option = getattr(self.options, name)
-        if option:
-            klass = import_class(option)
-        else:
-            klass = self.default_classes[name]
-        setattr(self.options, name, klass)
+        try:
+            option = getattr(self.options, name)
+            if option:
+                klass = import_class(option)
+            else:
+                klass = default
+            setattr(self.options, name, klass)
+        except Exception, e:
+            self.parser.error('Unable to import "%s": %s' % (name, e))
 
     def do_imports(self):
         """
         Import all importable options
         """
-        for option in self.default_classes.keys():
-            try:
-                self.do_import(option)
-            except Exception, e:
-                self.parser.error('Unable to import "%s": %s' % (option, e))
+        self.do_import('worker_class', Worker)
+        self.do_import('queue_model', self.options.worker_class.queue_model)
+        self.do_import('error_model', self.options.worker_class.error_model)
+        self.do_import('callback', self.options.worker_class.callback)
 
     def print_options(self):
         """
@@ -779,7 +777,10 @@ class WorkerConfig(object):
         print "The worker will run with the following options:"
         for name in self.options.worker_class.parameters:
             option = getattr(self.worker, name)
-            if isinstance(option, (list, tuple, set)):
+            if name == 'callback' and \
+                self.options.worker_class.execute == Worker.execute:
+                option = '<jobs "run" method>'
+            elif isinstance(option, (list, tuple, set)):
                 option = ','.join(option)
             print " - %s = %s" % (name.replace('_', '-'), option)
 
@@ -825,7 +826,16 @@ class WorkerConfig(object):
 
         if not self.worker.logger.handlers:
             handler = logging.StreamHandler()
-            handler.setFormatter(logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s'))
+            handler.setFormatter(logging.Formatter(
+                                        ' '.join(['[%(process)d]',
+                                                  # '%(asctime)s,%(msecs).03d',
+                                                  '%(asctime)s',
+                                                  '(%(name)s)',
+                                                  '%(levelname)-8s',
+                                                  '%(message)s',
+                                                 ])
+                                        # , '%y.%m.%d:%H.%M.%S'
+                                    ))
             self.worker.logger.addHandler(handler)
 
         if self.options.dry_run:
